@@ -25,6 +25,7 @@ pkg.require({ 'Gdk': '3.0',
               'Gtk': '3.0',
               'GWeather': '3.0' });
 
+const ByteArray = imports.byteArray;
 const Gdk = imports.gi.Gdk;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
@@ -37,6 +38,9 @@ const Window = imports.app.window;
 const World = imports.shared.world;
 const CurrentLocationController = imports.app.currentLocationController;
 
+const ShellIntegrationInterface = ByteArray.toString(
+    Gio.resources_lookup_data('/org/gnome/shell/ShellWeatherIntegration.xml', 0).get_data());
+
 function initEnvironment() {
     window.getApp = function() {
         return Gio.Application.get_default();
@@ -49,8 +53,13 @@ const Application = GObject.registerClass(
     _init() {
         super._init({ application_id: pkg.name,
                       flags: (Gio.ApplicationFlags.CAN_OVERRIDE_APP_ID |  Gio.ApplicationFlags.FLAGS_NONE) });
-        GLib.set_application_name(_("Weather"));
-        Gtk.Window.set_default_icon_name("org.gnome.Weather");
+
+        let name_prefix = '';
+        if (pkg.name.endsWith('Devel')) {
+            name_prefix = '(Development) ';
+        }
+        GLib.set_application_name(name_prefix + _("Weather"));
+        Gtk.Window.set_default_icon_name(pkg.name);
     }
 
     _onQuit() {
@@ -111,7 +120,7 @@ const Application = GObject.registerClass(
             parameter_type: new GLib.VariantType('v'),
         });
         showLocationAction.connect('activate', (action, parameter) => {
-            this._onShowLocation();
+            this._onShowLocation(action, parameter);
         });
         this.add_action(showLocationAction);
 
@@ -121,7 +130,7 @@ const Application = GObject.registerClass(
             parameter_type: new GLib.VariantType('v'),
         })
         showSearchAction.connect('activate', (action, parameter) => {
-            this._onShowSearch();
+            this._onShowSearch(action, parameter);
         });
         this.add_action(showSearchAction);
 
@@ -162,6 +171,16 @@ const Application = GObject.registerClass(
         this.add_accelerator("<Primary>q", "app.quit", null);
     }
 
+    vfunc_dbus_register(conn, path) {
+        this._shellIntegration = new ShellIntegration();
+        this._shellIntegration.export(conn, path);
+        return true;
+    }
+
+    vfunc_dbus_unregister(conn, path) {
+        this._shellIntegration.unexport(conn);
+    }
+
     _createWindow() {
         return new Window.MainWindow({ application: this });
     }
@@ -208,6 +227,40 @@ const Application = GObject.registerClass(
     }
 });
 
+let ShellIntegration = class ShellIntegration {
+    constructor() {
+        this._impl = Gio.DBusExportedObject.wrapJSObject(
+            ShellIntegrationInterface, this);
+
+        this._settings = new Gio.Settings({ schema_id: 'org.gnome.Weather' });
+
+        this._settings.connect('changed::automatic-location', () => {
+            this._impl.emit_property_changed('AutomaticLocation',
+                new GLib.Variant('b', this.AutomaticLocation));
+        });
+        this._settings.connect('changed::locations', () => {
+            this._impl.emit_property_changed('Locations',
+                new GLib.Variant('av', this.Locations));
+        });
+    }
+
+    export(connection, path) {
+        return this._impl.export(connection, path);
+    }
+
+    unexport(connection) {
+        return this._impl.unexport_from_connection(connection);
+    }
+
+    get AutomaticLocation() {
+        return this._settings.get_boolean('automatic-location');
+    }
+
+    get Locations() {
+        return this._settings.get_value('locations').deep_unpack();
+    }
+};
+
 function main(argv) {
     initEnvironment();
 
