@@ -103,15 +103,9 @@ var WorldModel = GObject.registerClass({
         let info = null;
         for (let i = locations.length - 1; i >= 0; i--) {
             let variant = locations[i];
-            let world = this._world.deserialize(variant);
-            if (world != null) {
-                let coords = world.get_coords();
-                let location = this._world.find_nearest_city(coords[0], coords[1]);
+            let location = this._world.deserialize(variant);
 
-                info = this._addLocationInternal(location, false);
-            } else {
-                log('Failed to deserialize location from GVariant:' + variant.print(true));
-            }
+            info = this._addLocationInternal(location, false);
         }
     }
 
@@ -230,6 +224,12 @@ var WorldModel = GObject.registerClass({
     }
 
     _addLocationInternal(newLocation, isCurrentLocation) {
+        for (let i = 0; i < this._infoList.length; i++) {
+            let info = this._infoList[i];
+            if (info.get_location().equal(newLocation))
+                return info;
+        }
+
         let info = new GWeather.Info({ location: newLocation,
                                        enabled_providers: this._providers });
         this._addInfoInternal(info, isCurrentLocation);
